﻿using System;
using System.Collections.Generic;
using System.ComponentModel.Composition;
using System.Text;
using Microsoft.VisualStudio.SharePoint;
using Microsoft.VisualStudio.SharePoint.Explorer;
using Microsoft.VisualStudio.SharePoint.Explorer.Extensions;
using System.Windows.Forms;
using Microsoft.SharePoint.Client;

namespace SeverExplorerExtensionDemo
{
    [Export(typeof(IExplorerNodeTypeExtension))]
    [ExplorerNodeType(ExtensionNodeTypes.FeatureNode)]
    internal class FeatureNodeExtension : IExplorerNodeTypeExtension
    {
        Guid definitionId;
        string featureName;
        IExplorerNodeContext siteContext;
        static string confirmationMessage = "如果停用此功能，所有与此功能关联的用户数据或自定义设置可能都会丢失。另外，所有依赖于此功能的活动功能可能都无法正常工作。";

        public void Initialize(IExplorerNodeType nodeType)
        {
            nodeType.NodeMenuItemsRequested += new EventHandler<ExplorerNodeMenuItemsRequestedEventArgs>(nodeType_NodeMenuItemsRequested);
        }
        
        void nodeType_NodeMenuItemsRequested(object sender, ExplorerNodeMenuItemsRequestedEventArgs e)
        {
            
            IMenuItem deactiveMenu = e.MenuItems.Add("停用");
            deactiveMenu.Click += new EventHandler<MenuItemEventArgs>(deactiveMenu_Click);

            IFeatureNodeInfo fn = e.Node.Annotations[typeof(IFeatureNodeInfo)] as IFeatureNodeInfo;
            definitionId = fn.Id;
            featureName = fn.Name;
            siteContext = e.Node.Context;

        }

        void deactiveMenu_Click(object sender, MenuItemEventArgs e)
        {
            if (MessageBox.Show(confirmationMessage, String.Format("停用 {0} 功能", featureName), MessageBoxButtons.YesNo, MessageBoxIcon.Exclamation) == DialogResult.Yes)
            {
                IExplorerNode parentFeatureNode = e.Owner as IExplorerNode;
                IExplorerNode featureNode = parentFeatureNode.ParentNode;
                ClientContext clientContext = new ClientContext(siteContext.SiteUrl.AbsoluteUri);
                Web site = clientContext.Web;
                FeatureCollection siteFeatures = site.Features;

                clientContext.Load(site, s => s.Title, s => s.Features);
                siteFeatures.Remove(definitionId, false);

                clientContext.ExecuteQuery();
                clientContext.Dispose();
                featureNode.Refresh();
             
            }

        }
    }
}